//
//  PanelPlugIn.m
//  Panel
//
//  Created by Dustin O'Connor on 6/6/11.
//  Copyright 2011 umaine. All rights reserved.
//

/* It's highly recommended to use CGL macros instead of changing the current context for plug-ins that perform OpenGL rendering */
#import <OpenGL/CGLMacro.h>

#import "PanelPlugIn.h"

#define	kQCPlugIn_Name				@"Panel"
#define	kQCPlugIn_Description		@"Panel description"

@implementation PanelPlugIn
@dynamic outputSaveFile, outputOpenFile, inputOpenAction, inputSaveAction, inputFileTypes, outputSave;

/*
Here you need to declare the input / output properties as dynamic as Quartz Composer will handle their implementation
@dynamic inputFoo, outputBar;
*/

+ (NSDictionary *)attributes
{
	/*
	Return a dictionary of attributes describing the plug-in (QCPlugInAttributeNameKey, QCPlugInAttributeDescriptionKey...).
	*/
	
	return [NSDictionary dictionaryWithObjectsAndKeys:kQCPlugIn_Name, QCPlugInAttributeNameKey, kQCPlugIn_Description, QCPlugInAttributeDescriptionKey, nil];
}

+ (NSDictionary *)attributesForPropertyPortWithKey:(NSString *)key
{
	/*
	Specify the optional attributes for property based ports (QCPortAttributeNameKey, QCPortAttributeDefaultValueKey...).
	*/
	
	return nil;
}

+ (QCPlugInExecutionMode)executionMode
{
	/*
	Return the execution mode of the plug-in: kQCPlugInExecutionModeProvider, kQCPlugInExecutionModeProcessor, or kQCPlugInExecutionModeConsumer.
	*/
	
	return kQCPlugInExecutionModeProcessor;
}

+ (QCPlugInTimeMode)timeMode
{
	/*
	Return the time dependency mode of the plug-in: kQCPlugInTimeModeNone, kQCPlugInTimeModeIdle or kQCPlugInTimeModeTimeBase.
	*/
	
	return kQCPlugInTimeModeIdle;
}

- (id)init
{
	self = [super init];
	if (self) {
		
		/*
		Allocate any permanent resource required by the plug-in.
		*/
	}
	
	return self;
}

- (void)finalize
{
	/*
	Release any non garbage collected resources created in -init.
	*/
	
	[super finalize];
}

- (void)dealloc
{
	/*
	Release any resources created in -init.
	*/

	[super dealloc];
}


@end

@implementation PanelPlugIn (Execution)

- (BOOL)startExecution:(id <QCPlugInContext>)context
{
	/*
	Called by Quartz Composer when rendering of the composition starts: perform any required setup for the plug-in.
	Return NO in case of fatal failure (this will prevent rendering of the composition to start).
	*/
	
	return YES;
}

- (void)enableExecution:(id <QCPlugInContext>)context
{

}



- (BOOL)execute:(id <QCPlugInContext>)context atTime:(NSTimeInterval)time withArguments:(NSDictionary *)arguments
{
	if(self.inputOpenAction)
		{
	NSOpenPanel * openPanel;
    openPanel = [NSOpenPanel openPanel];
    [openPanel setAllowsMultipleSelection:YES];
    [openPanel setCanChooseDirectories:YES];
    [openPanel setCanChooseFiles:YES];
    if([openPanel runModalForDirectory:nil file:nil types:self.inputFileTypes] != NSOKButton) 
		{NSLog(@"No file specified");}
    
    NSLog(@"file path %@", [openPanel filename]);
	
	self.outputOpenFile = [openPanel filename];
		}
	
	

	if(self.inputSaveAction)
		{
		
		NSSavePanel *save = [NSSavePanel savePanel];
		[save setAllowedFileTypes:self.inputFileTypes];
		
		int result = (int)[save runModal];
		
		if (result == NSOKButton){

			NSLog(@"file name %@", [save filename]);
			
			self.outputSaveFile = [save filename];
					self.outputSave = YES;
		}
		else
			{
			
			self.outputSave = NO;
			
			}

		}



	
	return YES;
}

- (void)disableExecution:(id <QCPlugInContext>)context
{
	/*
	Called by Quartz Composer when the plug-in instance stops being used by Quartz Composer.
	*/
}

- (void)stopExecution:(id <QCPlugInContext>)context
{

}

@end
